@@ -19,22 +19,23 @@
     clippy::unreadable_literal,
     clippy::must_use_candidate
 )]
+#![cfg_attr(docsrs, feature(doc_cfg, doc_auto_cfg))]
 
 use serde_json::Value;
 
 use error::{ParseError, ParseOrJsonError};
 use eval::EvalCtx;
 use idx::{Idx, IdxPath};
-use utils::{delete_paths, replace_paths};
+use utils::{delete_paths, replace_paths, try_replace_paths};
 
-mod ast;
+pub mod ast;
 pub mod error;
 mod eval;
-mod utils;
 pub mod idx;
+mod utils;
 
+#[doc(inline)]
 pub use ast::Path as JsonPath;
-use crate::utils::try_replace_paths;
 
 /// Find a pattern in the provided JSON value. Recompiles the pattern every call, if the same
 /// pattern is used a lot should instead try using [`JsonPath::compile`].
@@ -42,10 +43,7 @@ use crate::utils::try_replace_paths;
 /// # Errors
 ///
 /// - If the provided pattern fails to parse as a valid JSON path
-pub fn find<'a>(
-    pattern: &str,
-    value: &'a Value,
-) -> Result<Vec<&'a Value>, ParseError> {
+pub fn find<'a>(pattern: &str, value: &'a Value) -> Result<Vec<&'a Value>, ParseError> {
     Ok(JsonPath::compile(pattern)?.find(value))
 }
 
@@ -112,11 +110,7 @@ impl JsonPath {
     /// value returned by the provided function, then return the resulting object
     #[must_use = "this returns the new value, without modifying the original. To work in-place, \
                   use `replace_on`"]
-    pub fn replace(
-        &self,
-        value: &Value,
-        f: impl FnMut(&Value) -> Value,
-    ) -> Value {
+    pub fn replace(&self, value: &Value, f: impl FnMut(&Value) -> Value) -> Value {
         let paths = self.find_paths(value);
         let mut out = value.clone();
         replace_paths(paths, &mut out, f);
@@ -125,11 +119,7 @@ impl JsonPath {
 
     /// Replace items matched by this pattern on the provided JSON value, filling them the value
     /// returned by the provided function, operating in-place
-    pub fn replace_on(
-        &self,
-        value: &mut Value,
-        f: impl FnMut(&Value) -> Value,
-    ) {
+    pub fn replace_on(&self, value: &mut Value, f: impl FnMut(&Value) -> Value) {
         let paths = self.find_paths(value);
         replace_paths(paths, value, f);
     }
@@ -137,7 +127,7 @@ impl JsonPath {
     /// Replace or delete items matched by this pattern on the provided JSON value. Replaces if the
     /// provided method returns `Some`, deletes if the provided method returns `None`. This method
     /// then returns the resulting object
-    #[must_use = "this returns the new value, without modifying the origin. To work in-place, \
+    #[must_use = "this returns the new value, without modifying the original. To work in-place, \
                   use `try_replace_on`"]
     pub fn try_replace(&self, value: &Value, f: impl FnMut(&Value) -> Option<Value>) -> Value {
         let paths = self.find_paths(value);
